//
//  ItemSeriesView.swift
//  Jel
//
//  Created by zerocool on 2/12/24.
//

import SwiftUI
import JellyfinKit

struct ItemSeriesView: View {
  var item: BaseItemDto
  
  @State var pageScrolled: Bool = false
  
  var body: some View {
    VStack {
      ItemHeaderView(item: item)
        .foregroundStyle(.white)
        .background {
          GeometryReader {geo in
            EmptyView()
              .onChange(of: geo.frame(in: .global).minY) {
                let minY = geo.frame(in: .global).minY
                
                pageScrolled = minY < -150
              }
          }
        }
      
      ItemMediaView(item: item)
        .padding()
      
      ItemGenresView(item: item)
        .foregroundStyle(Color.primary)
      
      ItemSeriesSeasonsView(item: item)
        .foregroundStyle(Color.primary)
      
      ItemPeopleView(item: item)
        .foregroundStyle(Color.primary)
    }
    .navigationBarTitleDisplayMode(.inline)
    .navigationTitle(item.name ?? "Untitled")
    .toolbarRole(.editor)
    .toolbar {
      ToolbarItem(placement: .principal) {
        Text(pageScrolled ? item.name ?? "Untitled" : "")
          .bold()
      }
    }
    .toolbarBackground(pageScrolled ? .visible : .hidden)
  }
}

//#Preview {
//    ItemShowView()
//}
